use crate::get_pg;

use super::User;
pub trait ProfilePic {
    fn profile_pic(&self) -> impl std::future::Future<Output = Option<Vec<u8>>>;
    fn set_profile_pic(&self, image: Vec<u8>) -> impl std::future::Future<Output = ()>;
}

impl ProfilePic for User {
    /// Get a user's profile picture from the database
    async fn profile_pic(&self) -> Option<Vec<u8>> {
        let res: Option<(Vec<u8>,)> =
            sqlx::query_as("SELECT image FROM user_profile_pic WHERE username = $1;")
                .bind(&self.username)
                .fetch_optional(get_pg!())
                .await
                .unwrap();

        res.map(|x| x.0)
    }

    /// Set a user's profile picture in the database
    async fn set_profile_pic(&self, image: Vec<u8>) {
        sqlx::query("INSERT INTO user_profile_pic (username, image) VALUES ($1, $2) ON CONFLICT (id) DO UPDATE SET image = EXCLUDED.image",
        )
        .bind(&self.username)
        .bind(&image)
        .execute(get_pg!())
        .await.unwrap();
    }
}
